### Name: simrrdata
### Title: Simulating Randomized Response Scale Data (Forced Response
###   Design.
### Aliases: simrrdata
### Keywords: internal

### ** Examples

## Simulate MLIRT RR data
## Simulate dichotomous item response data of 1,000 persons responding to 10 items 
## Respondents are grouped equally over 50 groups.

N <- 1000                       #(1,000 respondents)
J <- 20                         #(respondents divided across 20 groups)
K <- 10                         #(responding to 10 items)       
nll <- rep(N/J,J)       #(equally divided across 20 groups)
C <- 1                          #(dichotomous responses)
S <- c(1,0,0,0)         #random intercept ability population model

outd <- simmlirtdata(N,J,K,C,nll,S)     #simulate MLIRT data

## Simulate RR data given randomizing device properties p1 = 4/3, q1 = 2/3
## Make use of simulated MLIRT parameters
## theta <- outd$theta #person parameters
## alpha <- outd$alpha #discrimination parameters
## beta <- outd$beta    #difficulty parameters 

outddata <- simrrdata(theta=outd$theta,alpha=outd$alpha,beta=outd$beta,C=1,p1=3/4,q1=2/3) 

## Estimate MLIRT model parameters given randomized response scale data 
out <- estMLIRT(Y=outddata$Yr,RR = outddata$RR, S=outd$S, nll=nll, XG=2000,XF=outd$XF, XR=outd$XR, W = outd$W,S2=outd$S2,
                                                scaling1=1,fixm=mean(outd$theta),fixsd=sqrt(var(outd$theta)))
MLIRTout(500,out)



